blink1_state
=======================

blink1_state is a state machine for the `Blink(1) <https://blink1.thingm.com/>`_
LED. It significantly simplifies the programmable pattern playing for one or
two colour patterns with an optional initial pause.

The audience for this is anyone who wants to concisely transition between
states for their Blink(1) within a Python script.

`The source for this project is available here
<https://github.com/tifoster/blink1_state>`_.

Copyright (c) 2018 Akamai Technologies, Inc.

----

This project was based on the Python Sample Project distributed from
`<https://packaging.python.org/>`_.

This is the README file for the project.

The file should use UTF-8 encoding and be written using `reStructuredText
<http://docutils.sourceforge.net/rst.html>`_. It
will be used to generate the project webpage on PyPI and will be displayed as
the project homepage on common code-hosting services, and should be written for
that purpose.

Typical contents for this file would include an overview of the project, basic
usage examples, etc. Generally, including the project changelog in here is not
a good idea, although a simple "What's New" section for the most recent version
may be appropriate.
